"use strict";

// Assumes shared code in session.js included here through the manifest.

let sessionsRegex = /(\/)([0-9][0-9])(-)([0-9][0-9])(\/)/;

function handleContentHide(request, sender, sendResponse) {
  chrome.pageAction.setIcon({tabId: sender.tab.id, path: "icons/gray_arrows.svg"});
  chrome.pageAction.hide(sender.tab.id);
}


function handleContentShow(request, sender, sendResponse) {
  if (sender.url.search(thisSession) >= 0) {
    chrome.pageAction.setIcon({tabId: sender.tab.id, path: "icons/gray_arrows.svg"});
    chrome.pageAction.show(sender.tab.id);
  } else if (sender.url.match(sessionsRegex)) {
    if (Number(sender.url.match(sessionsRegex)[0].slice(1, 3)) < Number(thisSession.slice(0, 2))) {
      chrome.pageAction.setIcon({tabId: sender.tab.id, path: "icons/red_arrows.svg"});
    } else {
      chrome.pageAction.setIcon({tabId: sender.tab.id, path: "icons/green_arrows.svg"});
    }
    chrome.pageAction.show(sender.tab.id);
  } else {
    handleContentHide(request, sender, sendResponse);
  }
}


let SESSIONS;
let BASE_URL;
let TAB;
function handleMenuInit(request, sender, sendResponse) {
  let cur;
  let prev;
  let next;
  chrome.tabs.query({active: true, currentWindow: true}, tabs => {
    TAB = tabs[0];
    BASE_URL = TAB && TAB.url;
    if (BASE_URL) {
      if (BASE_URL.search(thisSession) >= 0) {
        cur = undefined;
        prev = sessionString(curStartYear - 1);
        next = sessionString(curStartYear + 1);
      } else {
        let match = BASE_URL.match(sessionsRegex);
        cur = thisSession;
        let startYear = Number(match[2]);
        prev = sessionString(startYear - 1);
        next = sessionString(startYear + 1);
      }
      SESSIONS = {cur: cur, prev: prev, next: next};
      sendResponse(SESSIONS);
    }
  });
}


function handleMenu(request, sender, sendResponse) {
  let newURL = BASE_URL.replace(sessionsRegex, '$1' + SESSIONS[request.menu] + '$5');
  chrome.tabs.update(TAB.id, {url: newURL});
  sendResponse(true);
}


function handleMessage(request, sender, sendResponse) {
  const dispatch = {
    'src_content_hide': handleContentHide,
    'src_content_show': handleContentShow,
    'src_menu_init': handleMenuInit,
    'src_menu': handleMenu
  };
  let key = "src_" + request.source;
  if (key in dispatch) {
    dispatch[key](request, sender, sendResponse);
  } else {
    console.log("background.js didn't recognize request", request);
  }
  return true;
};
chrome.runtime.onMessage.addListener(handleMessage);
